@@ -216,7 +216,7 @@ class Scan:
         theta_axis_name="dcdtheta",
         energy=None,
         pixel_max=1000000,
-        hot_pixel_threshold=200000
+        hot_pixel_threshold=200000,
         transpose=False,
     ):
         self.file_path = file_path
